Struct
QmiMessageDmsSwiGetUsbCompositionOutput
since: 1.20
Description [src]
struct QmiMessageDmsSwiGetUsbCompositionOutput {
/* No available fields */
}
The QmiMessageDmsSwiGetUsbCompositionOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.20
Instance methods
qmi_message_dms_swi_get_usb_composition_output_get_current
Get the ‘Current’ field from self.
since: 1.20
qmi_message_dms_swi_get_usb_composition_output_get_result
Get the result of the QMI operation.
since: 1.20
qmi_message_dms_swi_get_usb_composition_output_get_supported
Get the ‘Supported’ field from self.
since: 1.20
qmi_message_dms_swi_get_usb_composition_output_ref
Atomically increments the reference count of self by one.
since: 1.20
qmi_message_dms_swi_get_usb_composition_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.20